Documentation
¶
Overview ¶
Package consumer contains interfaces that receive and process consumerdata.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Capabilities ¶ added in v0.27.0
type Capabilities struct {
// MutatesData is set to true if Consume* function of the
// processor modifies the input TraceData or MetricsData argument.
// Processors which modify the input data MUST set this flag to true. If the processor
// does not modify the data it MUST set this flag to false. If the processor creates
// a copy of the data before modifying then this flag can be safely set to false.
MutatesData bool
}
Capabilities describes the capabilities of a Processor.
type Logs ¶ added in v0.23.0
type Logs interface {
// ConsumeLogs receives pdata.Logs for consumption.
ConsumeLogs(ctx context.Context, ld pdata.Logs) error
// contains filtered or unexported methods
}
Logs is an interface that receives pdata.Logs, processes it as needed, and sends it to the next processing node if any or to the destination.
type Metrics ¶ added in v0.23.0
type Metrics interface {
// ConsumeMetrics receives pdata.Metrics for consumption.
ConsumeMetrics(ctx context.Context, md pdata.Metrics) error
// contains filtered or unexported methods
}
Metrics is the new metrics consumer interface that receives pdata.Metrics, processes it as needed, and sends it to the next processing node if any or to the destination.
type Traces ¶ added in v0.23.0
type Traces interface {
// ConsumeTraces receives pdata.Traces for consumption.
ConsumeTraces(ctx context.Context, td pdata.Traces) error
// contains filtered or unexported methods
}
Traces is an interface that receives pdata.Traces, processes it as needed, and sends it to the next processing node if any or to the destination.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package consumererror provides wrappers to easily classify errors.
|
Package consumererror provides wrappers to easily classify errors. |
|
consumererrorprofiles
module
|
|
|
xconsumererror
module
|
|
|
consumerprofiles
module
|
|
|
Package pdata (pipeline data) implements data structures that represent telemetry data in-memory.
|
Package pdata (pipeline data) implements data structures that represent telemetry data in-memory. |
|
xconsumer
module
|
Click to show internal directories.
Click to hide internal directories.